@@ -82,6 +82,8 @@ extern crate lazy_static;
 
 #[cfg(feature = "record")]
 pub use record::{config::RecordConfig, StubrRecord};
+#[cfg(feature = "record")]
+pub use record::core::Record;
 #[cfg(all(feature = "record", feature = "record-isahc"))]
 pub use record::client::isahc_client;
 #[cfg(all(feature = "record", feature = "record-reqwest"))]
@@ -91,6 +93,8 @@ pub use server::{config::Config, Stubr};
 pub use stubr_attributes::apps;
 #[cfg(feature = "attributes")]
 pub use stubr_attributes::mock;
+#[cfg(feature = "verify")]
+pub use verify::StubrVerify;
 #[cfg(all(feature = "record", feature = "attributes"))]
 pub use stubr_attributes::record;
 
@@ -98,4 +102,6 @@ mod model;
 mod server;
 mod cloud;
 #[cfg(feature = "record")]
-mod record;
\ No newline at end of file
+mod record;
+#[cfg(feature = "verify")]
+mod verify;
\ No newline at end of file
